# mypyy

This package contains Python practicals from basic IO to file handling.

## Installation

```bash
pip install mypyy
```

## Usage

```python
import py

# List available practicals
py.help()

# Run a specific practical
py.basic_io()
py.list_ops()
py.file_handling()

# Run ALL practicals
py.all()
```
